@@ -32,6 +32,14 @@
 #include <string.h>
 #include <time.h>
 
+#include <errno.h>
+#include <sys/types.h>
+#if !defined (WIN32)
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#endif
+
 #include "filelib.h"
 #include "socklib.h"
 #include "http.h"
@@ -63,7 +71,6 @@ static void			ripthread(void *bla);
 static int			myrecv(char* buffer, int size);
 static error_code		start_relay(int content_type);
 static void			post_status(int status);
-static int			set_output_directory();
 //static error_code		start_track(char *track);
 //static error_code		rip_manager_end_track(char *track);
 //static error_code		rip_manager_put_data(char *buf, int size);
@@ -86,6 +93,7 @@ static IO_GET_STREAM		m_ripin;		// Raw stream data + song information
 static void			(*m_status_callback)(int message, void *data);
 static BOOL			m_ripping = FALSE;
 static u_long			m_bytes_ripped;
+static BOOL			m_write_data = TRUE;	// Should we actually write to a file or not
 static HSEM			m_started_sem;	// to prevent deadlocks when ripping is stopped before its
 													// started.
 
@@ -221,19 +229,29 @@ rip_manager_start_track (TRACK_INFO* ti, int track_count)
 {
     int ret;
 
-    /* GCS FIX */
+#if defined (commmentout)
+    /* GCS FIX -- here is where i would compose the incomplete filename */
     char* trackname = ti->raw_metadata;
-
     debug_printf("rip_manager_start_track: %s\n", trackname);
+    if (m_write_data && (ret = filelib_start(trackname)) != SR_SUCCESS) {
+        return ret;
+    }
+#endif
 
-    if ((ret = filelib_start(trackname)) != SR_SUCCESS) {
+    m_write_data = ti->save_track;
+
+    if (m_write_data && (ret = filelib_start (ti)) != SR_SUCCESS) {
         return ret;
     }
 
-    strcpy(m_ripinfo.filename, trackname);
     m_ripinfo.filesize = 0;
     m_ripinfo.track_count = track_count;
-    m_status_callback(RM_NEW_TRACK, (void *)trackname);
+
+    /* Compose the string for the console output */
+    snprintf (m_ripinfo.filename, SR_MAX_PATH, "%s - %s", 
+	      ti->artist, ti->title);
+    m_ripinfo.filename[SR_MAX_PATH-1] = '\0';
+    m_status_callback(RM_NEW_TRACK, (void*) m_ripinfo.filename);
     post_status(0);
 
     return SR_SUCCESS;
@@ -249,8 +267,11 @@ rip_manager_end_track(TRACK_INFO* ti)
 {
     char fullpath[SR_MAX_PATH];
 
-    /* GCS FIX */
-    filelib_end(ti->raw_metadata, GET_OVER_WRITE_TRACKS(m_options.flags), GET_TRUNCATE_DUPS(m_options.flags), fullpath, m_options.szPrefix);
+    if (m_write_data) {
+        filelib_end (ti, GET_OVER_WRITE_TRACKS(m_options.flags),
+		     GET_TRUNCATE_DUPS(m_options.flags), fullpath);
+    }
+
     post_status(0);
     m_status_callback(RM_TRACK_DONE, (void*)fullpath);
 
@@ -260,7 +281,8 @@ rip_manager_end_track(TRACK_INFO* ti)
 error_code
 rip_manager_put_data(char *buf, int size)
 {
-    filelib_write_track(buf, size);
+    if (m_write_data)
+        filelib_write_track(buf, size);
 
     m_ripinfo.filesize += size;
     m_bytes_ripped += size;
@@ -277,30 +299,6 @@ rip_manager_put_raw_data(char *buf, int size)
 }
 
 
-/* GCS - Honestly, the filename code needs to be ripped out and rewritten.
-   Problems include: (1) no wchar support, (2) truncation and stripping
-   should not be applied to ID3 data, (3) MAX_PATH and NAME_MAX should 
-   be properly used, or even better pathconf (see glibc manual for example),
-   (4) why is it smeared across rip_manager.c and filelib.c ?
-
-   But "for now", I've hacked it to do better truncation at least in this 
-   limited circumstance: ASCII streams with MAX_PATH == NAME_MAX.
-*/
-int
-set_output_directory()
-{
-    int rc;
-    rc = filelib_set_output_directory (m_options.output_directory, 
-	GET_SEPERATE_DIRS(m_options.flags),
-	GET_DATE_STAMP(m_options.flags),
-	m_info.icy_name);
-    if (rc != SR_SUCCESS)
-	return rc;
-//    m_status_callback(RM_OUTPUT_DIR, (void*)newpath);
-    m_status_callback(RM_OUTPUT_DIR, (void*)filelib_get_output_directory);
-    return rc;
-}
-
 /* 
  * Fires up the relaylib stuff. Most of it is so relaylib 
  * knows what to call the stream which is what the 'construct_sc_repsonse()'
@@ -486,6 +484,31 @@ destroy_subsystems()
     filelib_shutdown();
 }
 
+int
+create_pls_file()
+{
+    FILE *fid;
+
+    if  ('\0' == m_options.relay_ip[0]) {
+	fprintf(stderr, "can not determine relaying ip, pass ip to -r \n");
+	return -1;
+    }
+
+    fid = fopen(m_options.pls_file, "w");
+
+    if (NULL == fid) {
+	fprintf(stderr, "could not create playlist file '%s': %d '%s'\n",
+		m_options.pls_file, errno, strerror(errno));
+    } else {
+	fprintf(fid, "[playlist]\n");
+	fprintf(fid, "NumberOfEntries=1\n");
+	fprintf(fid, "File1=http://%s:%d\n", m_options.relay_ip, m_options.relay_port);
+	fclose(fid);
+    }
+		
+    return 0;
+}
+
 error_code
 start_ripping()
 {
@@ -526,18 +549,27 @@ start_ripping()
     strcpy(m_ripinfo.streamname, m_info.icy_name);
     strcpy(m_ripinfo.server_name, m_info.server);
 
-    /* GCS testing... moved from rip_manager_start() */
-    filelib_init(GET_INDIVIDUAL_TRACKS(m_options.flags),
-		 GET_COUNT_FILES(m_options.flags),
-		 GET_KEEP_INCOMPLETE(m_options.flags),
-		 GET_SINGLE_FILE_OUTPUT(m_options.flags),
-		 m_info.content_type, 
-		 m_options.output_file);
-
-    ret = set_output_directory();
-    if (ret != SR_SUCCESS) {
+    /* Initialize file writing code. */
+    ret = filelib_init
+	    (GET_INDIVIDUAL_TRACKS(m_options.flags),
+	     GET_COUNT_FILES(m_options.flags),
+	     m_options.count_start,
+	     GET_KEEP_INCOMPLETE(m_options.flags),
+	     GET_SINGLE_FILE_OUTPUT(m_options.flags),
+	     m_info.content_type, 
+	     m_options.output_file,
+	     m_options.output_directory,
+	     m_options.output_pattern,
+	     GET_SEPERATE_DIRS(m_options.flags),
+	     GET_DATE_STAMP(m_options.flags),
+	     m_info.icy_name);
+    if (ret != SR_SUCCESS)
 	goto RETURN_ERR;
-    }
+
+#if defined (commentout)
+    /* This doesn't seem to be used */
+    m_status_callback(RM_OUTPUT_DIR, (void*)filelib_get_output_directory);
+#endif
 
     /* prepares the ripshout lib for ripping */
     ret = ripshout_init(&m_in, &m_ripin, m_info.meta_interval);
@@ -575,12 +607,17 @@ start_ripping()
 	ret = relaylib_init(GET_SEARCH_PORTS(m_options.flags), 
 			    m_options.relay_port, m_options.max_port, 
 			    &new_port, m_options.if_name, 
-			    m_options.max_connections);
+			    m_options.max_connections, m_options.relay_ip);
 	if (ret != SR_SUCCESS) {
 		goto RETURN_ERR;
 	}
+
 	m_options.relay_port = new_port;
 	start_relay(m_info.content_type);
+
+	if (0 != m_options.pls_file[0]) {
+		create_pls_file(new_port);
+	}
     }
     post_status(RM_STATUS_BUFFERING);
     return SR_SUCCESS;
@@ -608,12 +645,6 @@ rip_manager_start(void (*status_callback)(int message, void *data),
     if (!options)
 	return SR_ERROR_INVALID_PARAM;
 
-#if defined (commentout)
-    filelib_init(GET_COUNT_FILES(options->flags),
-		 GET_KEEP_INCOMPLETE(options->flags),
-		 GET_SINGLE_FILE_OUTPUT(options->flags),
-		 options->output_file);
-#endif
     socklib_init();
 
     init_error_strings();
@@ -655,6 +686,9 @@ set_rip_manager_options_defaults (RIP_MANAGER_OPTIONS *m_opt)
     m_opt->max_connections = 1;
 
     strcpy(m_opt->output_directory, "./");
+    m_opt->output_pattern[0] = 0;
+    m_opt->relay_ip[0] = 0;
+    m_opt->pls_file[0] = 0;
     m_opt->proxyurl[0] = 0;
     m_opt->url[0] = 0;
     m_opt->output_file[0] = 0;
