@@ -1,9 +1,9 @@
 #ifndef __RIP_MANANGER_H__
 #define __RIP_MANANGER_H__
 
-#include "types.h"
+#include "srtypes.h"
 
-#define SRVERSION	"1.61.7"
+#define SRVERSION	"1.61.9"
 
 #if defined (WIN32)
 #define SRPLATFORM      "windows"
@@ -14,10 +14,10 @@
 #define MAX_STATUS_LEN		256
 #define MAX_STREAMNAME_LEN	1024
 #define MAX_SERVER_LEN		1024
-#define MAX_PREFIX_LEN 50
 
 // Messages for status_callback hook in rip_manager_init()
-// used for notifing to client whats going on *DO NOT* call rip_mananger_start or rip_mananger_stop from
+// used for notifing to client whats going on *DO NOT* call 
+// rip_mananger_start or rip_mananger_stop from
 // these functions!!! it will cause a deadlock
 #define RM_UPDATE	0x01		// returns a pointer RIP_MANAGER_INFO struct
 #define RM_ERROR	0x02		// returns the error code
@@ -25,13 +25,14 @@
 #define RM_STARTED	0x04		// NULL
 #define RM_NEW_TRACK	0x05		// Name of the new track
 #define RM_TRACK_DONE	0x06		// pull path of the track completed
+// RM_OUTPUT_DIR is now OBSOLETE
 #define RM_OUTPUT_DIR	0x07		// Full path of the output directory
 
 
 // The following are the possible status values for RIP_MANAGER_INFO
 #define RM_STATUS_BUFFERING		0x01
 #define RM_STATUS_RIPPING		0x02
-#define RM_STATUS_RECONNECTING	0x03
+#define RM_STATUS_RECONNECTING		0x03
 
 
 typedef struct RIP_MANAGER_INFOst
@@ -99,9 +100,12 @@ typedef struct RIP_MANAGER_OPTIONSst
     char url[MAX_URL_LEN];		// url of the stream to connect to
     char proxyurl[MAX_URL_LEN];		// url of a http proxy server, '\0' otherwise
     char output_directory[SR_MAX_PATH];	// base directory to output files too
+    char output_pattern[SR_MAX_PATH];	// filename pattern when ripping with splitting
     char output_file[SR_MAX_PATH];	// filename base when ripping without splitting
     char if_name[SR_MAX_PATH];		// local interface to use
     char rules_file[SR_MAX_PATH];       // file that holds rules for parsing metadata
+    char pls_file[SR_MAX_PATH];		// optional, where to create a .pls file
+    char relay_ip[SR_MAX_PATH];		// optional, ip to bind relaying socket to
     int relay_port;			// port to use for the relay server
     u_short max_port;			// highest port the relay server can look if it needs to search
     int max_connections;                // max number of connections to relay stream
@@ -113,7 +117,8 @@ typedef struct RIP_MANAGER_OPTIONSst
     int timeout;			// timeout, in seconds, before a stalled connection is forcefully closed
     int dropcount;			// number of tracks at beginning of connection to always ignore
     CODESET_OPTIONS cs_opt;             // which codeset should i use?
-    char szPrefix[MAX_PREFIX_LEN];      // might want to use a prefix for each file
+    int count_start;                    // which number to start counting?
+
 } RIP_MANAGER_OPTIONS;
 
 typedef struct ERROR_INFOst
