@@ -26,7 +26,7 @@
 #endif
 #include <stdio.h>
 #include <time.h>
-#include "types.h"
+#include "srtypes.h"
 #include "util.h"
 #include "threadlib.h"
 #include "debug.h"
