@@ -24,7 +24,7 @@
 #if defined HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if defined HAVE_WCHAR_T
+#if defined HAVE_WCHAR_SUPPORT
 #if defined HAVE_WCHAR_H
 #include <wchar.h>
 #endif
@@ -44,7 +44,7 @@
 #include <langinfo.h>
 #endif
 #include "debug.h"
-#include "types.h"
+#include "srtypes.h"
 
 
 /* uncomment to use new i18n code */
@@ -60,7 +60,6 @@ int	word_count(char *str);
 char	*subnstr_until(const char *str, char *until, char *newstr, int maxlen);
 char	*strip_invalid_chars(char *str);
 char	*format_byte_size(char *str, long size);
-char	*add_trailing_slash(char *str);
 void	trim(char *str);
 void 	null_printf(char *s, ...);
 
@@ -74,20 +73,6 @@ const char* codeset_id3;
 const char* codeset_filesys;
 
 
-char*
-add_trailing_slash (char *str)
-{
-#if WIN32
-    if (str[strlen(str)-1] != '\\')
-	strcat(str, "\\");
-#else
-    if (str[strlen(str)-1] != '/')
-	strcat(str, "/");
-#endif
-
-    return str;
-}
-
 char *subnstr_until(const char *str, char *until, char *newstr, int maxlen)
 {
     const char *p = str;
@@ -114,7 +99,7 @@ char *left_str(char *str, int len)
     return str;
 }
 
-#if HAVE_WCHAR_T
+#if HAVE_WCHAR_SUPPORT
 # if HAVE_ICONV
 int 
 iconv_convert_string (char* dst, int dst_len, char* src,
@@ -190,7 +175,7 @@ wstring_from_string (wchar_t* w, int wlen, char* c, const char* codeset)
     }
     return 0;
 }
-#endif /* HAVE_WCHAR_T */
+#endif /* HAVE_WCHAR_SUPPORT */
 
 void
 set_codeset (char* codeset_type, const char* codeset)
@@ -390,7 +375,8 @@ suggest_filenames (char *input_string, char *utf8_name, char *wchar_name,
 }
 #endif
 
-#if HAVE_WCHAR_T
+#if HAVE_WCHAR_SUPPORT
+# if HAVE_ICONV
 char*
 strip_invalid_chars_testing(char *str)
 {
@@ -491,6 +477,7 @@ strip_invalid_chars_testing(char *str)
 
     return str;
 }
+# endif /* HAVE_ICONV */
 
 char*
 strip_invalid_chars_stable(char *str)
@@ -505,7 +492,6 @@ strip_invalid_chars_stable(char *str)
 					   *(strlen(invalid_chars)+2));
     wchar_t replacement;
     wchar_t *wstrp;
-    int i;
     size_t t;
 
     debug_printf ("strip_invalid_chars() mb_in:\n");
@@ -584,7 +570,7 @@ strip_invalid_chars_stable(char *str)
 
     return str;
 }
-#endif /* HAVE_WCHAR_T */
+#endif /* HAVE_WCHAR_SUPPORT */
 
 char*
 strip_invalid_chars_no_wchar(char *str)
@@ -609,49 +595,10 @@ strip_invalid_chars_no_wchar(char *str)
     return str;
 }
 
-void
-parse_artist_title (char* artist, char* title, char* album, 
-		    int bufsize, char* trackname)
-{
-    char *p1,*p2;
-
-    /* Parse artist, album & title. Look for a '-' in the track name,
-     * i.e. Moby - sux0rs (artist/track)
-     */
-    memset(album, '\000', bufsize);
-    memset(artist, '\000', bufsize);
-    memset(title, '\000', bufsize);
-    p1 = strchr(trackname, '-');
-    if (p1) {
-	strncpy(artist, trackname, p1-trackname);
-	p1++;
-	p2 = strchr(p1, '-');
-	if (p2) {
-	    if (*p1 == ' ') {
-		p1++;
-	    }
-	    strncpy(album, p1, p2-p1);
-	    p2++;
-	    if (*p2 == ' ') {
-		p2++;
-	    }
-	    strcpy(title, p2);
-	} else {
-	    if (*p1 == ' ') {
-		p1++;
-	    }
-	    strcpy(title, p1);
-	}
-    } else {
-        strcpy(artist, trackname);
-        strcpy(title, trackname);
-    }
-}
-
 char* 
 strip_invalid_chars(char *str)
 {
-#if HAVE_WCHAR_T
+#if HAVE_WCHAR_SUPPORT
 #if defined (NEW_I18N_CODE)
     return strip_invalid_chars_testing(str);
 #else
